import typographyTokens from '@highlight-ui/tokens/dist/typography/typography.json';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { TypographyColorTokenType, FontFamilyTokenType, FontSizeTokenType, FontWeightTokenType, LetterSpacingTokenType, LineHeightTokenType, TextCaseTokenType, TextDecorationTokenType } from '@highlight-ui/tokens';
export declare type TypographyToken = keyof typeof typographyTokens;
export declare type TypographyColorToken = TypographyColorTokenType;
export declare type TypographyFontFamilyToken = FontFamilyTokenType;
export declare type TypographyFontSizeToken = FontSizeTokenType;
export declare type TypographyFontWeightToken = FontWeightTokenType;
export declare type TypographyTextCaseToken = TextCaseTokenType;
export declare type TypographyTextDecorationToken = TextDecorationTokenType;
export declare type TypographyLetterSpacingToken = LetterSpacingTokenType;
export declare type TypographyLineHeightToken = LineHeightTokenType;
declare type TypographyAsProps = 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'p' | 'span';
export declare type BaseTypographyProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Specifies an HTML tag for rendering the element */
    as?: TypographyAsProps;
    /** Specifies font family */
    fontFamily?: TypographyFontFamilyToken;
    /** Specifies font size */
    fontSize?: TypographyFontSizeToken;
    /** Specifies font weight */
    fontWeight?: TypographyFontWeightToken;
    /** Specifies letter spacing */
    letterSpacing?: TypographyLetterSpacingToken;
    /** Specifies line height */
    lineHeight?: TypographyLineHeightToken;
    /** Specifies text case */
    textTransform?: TypographyTextCaseToken;
    /** Specifies text decoration */
    textDecoration?: TypographyTextDecorationToken;
    /** Specifies a text color */
    color?: TypographyColorToken;
    /** Whether to truncate the text */
    truncate?: boolean;
}> & Pick<React.HTMLAttributes<HTMLElement>, 'id' | 'title'>>;
/**
 * @deprecated This type is deprecated and will be removed in future releases.
 * Please use `HeadingProps` or `BodyProps` instead.
 */
export declare type TokenisedTypographyProps = PropsWithMetadata<{
    /** Specifies typography token (Ignores `variant` if specified) */
    token?: TypographyToken;
    /** Specifies font family (Ignored if `variant` is specified) */
    fontFamily?: TypographyFontFamilyToken;
    /** Specifies font size (Ignored if `variant` is specified) */
    fontSize?: TypographyFontSizeToken;
    /** Specifies font weight (Ignored if `variant` is specified) */
    fontWeight?: TypographyFontWeightToken;
    /** Specifies letter spacing (Ignored if `variant` is specified) */
    letterSpacing?: TypographyLetterSpacingToken;
    /** Specifies line height (Ignored if `variant` is specified) */
    lineHeight?: TypographyLineHeightToken;
    /** Specifies text case (Ignored if `variant` is specified) */
    textTransform?: TypographyTextCaseToken;
    /** Specifies text decoration (Ignored if `variant` is specified) */
    textDecoration?: TypographyTextDecorationToken;
}> & React.PropsWithChildren<{
    /** Allows providing a custom class name */
    className?: string;
    /** Specifies an HTML tag for rendering the element */
    component?: string;
    /** Specifies a color of the typography */
    color?: TypographyColorToken;
}> & React.HTMLAttributes<HTMLElement> & React.ButtonHTMLAttributes<HTMLElement>;
/**
 * @deprecated This type is deprecated and will be removed in future releases.
 * Please use `HeadingProps` or `BodyProps` instead.
 */
export declare type TypographyProps = TokenisedTypographyProps;
export declare type BodyVariant = 'base' | 'small' | 'large' | 'strong-base' | 'strong-small' | 'strong-large';
export declare type HeadingVariant = '2xlarge' | 'xlarge' | 'large' | 'medium' | 'small' | 'xsmall';
export declare type BodyProps = React.PropsWithChildren<{
    /** Specifies the variant of body */
    variant?: BodyVariant;
    /** Specifies an HTML tag for rendering the body element */
    as?: Extract<TypographyAsProps, 'p' | 'span'>;
} & Pick<BaseTypographyProps, 'metadata' | 'color' | 'truncate' | 'id' | 'title'>>;
export declare type HeadingProps = React.PropsWithChildren<{
    /** Specifies the variant of the heading */
    variant: HeadingVariant;
    /** Specifies an HTML tag for rendering the heading element */
    as: Exclude<TypographyAsProps, 'p'>;
} & Pick<BaseTypographyProps, 'metadata' | 'color' | 'truncate' | 'id' | 'title'>>;
export declare type BodyVariantProps = Record<BodyVariant, {
    fontSize: TypographyFontSizeToken;
    lineHeight: TypographyLineHeightToken;
    fontWeight: TypographyFontWeightToken;
}>;
export declare type HeadingVariantProps = Record<HeadingVariant, {
    fontSize: TypographyFontSizeToken;
    lineHeight: TypographyLineHeightToken;
}>;
export {};
